=====
Array
=====

The following methods are available under the `DataTypeExpr.arr` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    DataTypeExpr.arr.inner_dtype
    DataTypeExpr.arr.width
    DataTypeExpr.arr.shape
